package
Version:
v0.0.0-...-d0d7a61
Opens a new window with list of versions in this module.
Published: Apr 19, 2019
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Login struct {
Email string `form:"email" json:"Email" binding:"required"`
Password string `form:"password" json:"Password" binding:"required"`
}
Login ...
Source Files
¶
Click to show internal directories.
Click to hide internal directories.